@@ -46,18 +46,14 @@ struct DownloadConfig
     bool bRemoteXML;
     bool bSaveChangelogs;
     bool bSaveSerials;
+    bool bSaveLogo;
     bool bAutomaticXMLCreation;
-
-    bool bInstallers;
-    bool bExtras;
-    bool bPatches;
-    bool bLanguagePacks;
-    bool bDLC;
+    bool bFreeSpaceCheck;
 
     bool bIgnoreDLCCount;
     bool bDuplicateHandler;
     bool bGalaxyDependencies;
-    bool bGalaxyDeleteOrphans;
+    bool bDeleteOrphans;
 };
 
 struct gameSpecificConfig
@@ -239,6 +235,7 @@ class Config
         bool bDownload;
         bool bRepair;
         bool bUpdated;
+        bool bNew;
         bool bCheckStatus;
         bool bShowWishlist;
         bool bNotifications;
@@ -253,6 +250,7 @@ class Config
 #ifdef USE_QT_GUI_LOGIN
         bool bEnableLoginGUI;
 #endif
+        bool bUseFastCheck;
 
         // Cache
         bool bUseCache;
@@ -281,6 +279,7 @@ class Config
         std::string sIgnorelistFilePath;
         std::string sGameHasDLCListFilePath;
         std::string sReportFilePath;
+        std::string sTransformConfigFilePath;
 
         std::string sXMLFile;
 
@@ -320,6 +319,8 @@ class Config
         int iProgressInterval;
         int iMsgLevel;
         unsigned int iListFormat;
+
+        Json::Value transformationsJSON;
 };
 
 #endif // CONFIG_H__
