@@ -32,18 +32,23 @@ class gameDetails
         std::string icon;
         std::string serials;
         std::string changelog;
+        std::string logo;
         void filterWithPriorities(const gameSpecificConfig& config);
         void makeFilepaths(const DirectoryConfig& config);
         std::string getSerialsFilepath();
+        std::string getLogoFilepath();
         std::string getChangelogFilepath();
         Json::Value getDetailsAsJson();
         std::vector<gameFile> getGameFileVector();
         std::vector<gameFile> getGameFileVectorFiltered(const unsigned int& iType);
+        void filterWithType(const unsigned int& iType);
         virtual ~gameDetails();
     protected:
         void filterListWithPriorities(std::vector<gameFile>& list, const gameSpecificConfig& config);
+        void filterListWithType(std::vector<gameFile>& list, const unsigned int& iType);
     private:
         std::string serialsFilepath;
+        std::string logoFilepath;
         std::string changelogFilepath;
 };
 
