@@ -38,6 +38,7 @@ struct gameItem
     std::vector<std::string> dlcnames;
     Json::Value gamedetailsjson;
     int updates = 0;
+    bool isnew;
 };
 
 struct wishlistItem
@@ -70,7 +71,7 @@ namespace Util
     void filepathReplaceReservedStrings(std::string& str, const std::string& gamename, const unsigned int& platformId = 0, const std::string& dlcname = "");
     void setFilePermissions(const boost::filesystem::path& path, const boost::filesystem::perms& permissions);
     int getTerminalWidth();
-    void getDownloaderUrlsFromJSON(const Json::Value &root, std::vector<std::string> &urls);
+    void getManualUrlsFromJSON(const Json::Value &root, std::vector<std::string> &urls);
     std::vector<std::string> getDLCNamesFromJSON(const Json::Value &root);
     std::string getHomeDir();
     std::string getConfigHome();
@@ -79,7 +80,7 @@ namespace Util
     unsigned int getOptionValue(const std::string& str, const std::vector<GlobalConstants::optionsStruct>& options, const bool& bAllowStringToIntConversion = true);
     std::string getOptionNameString(const unsigned int& value, const std::vector<GlobalConstants::optionsStruct>& options);
     void parseOptionString(const std::string &option_string, std::vector<unsigned int> &priority, unsigned int &type, const std::vector<GlobalConstants::optionsStruct>& options);
-    std::string getLocalFileHash(const std::string& xml_dir, const std::string& filepath, const std::string& gamename = std::string());
+    std::string getLocalFileHash(const std::string& xml_dir, const std::string& filepath, const std::string& gamename = std::string(), const bool& useFastCheck = true);
     void shortenStringToTerminalWidth(std::string& str);
     std::string getJsonUIntValueAsString(const Json::Value& json);
     std::string getStrippedString(std::string str);
@@ -92,6 +93,7 @@ namespace Util
     curl_off_t CurlWriteMemoryCallback(char *ptr, curl_off_t size, curl_off_t nmemb, void *userp);
     curl_off_t CurlWriteChunkMemoryCallback(void *contents, curl_off_t size, curl_off_t nmemb, void *userp);
     curl_off_t CurlReadChunkMemoryCallback(void *contents, curl_off_t size, curl_off_t nmemb, ChunkMemoryStruct *userp);
+    std::string makeSizeString(const unsigned long long& iSizeInBytes);
 
     template<typename ... Args> std::string formattedString(const std::string& format, Args ... args)
     {
@@ -100,6 +102,8 @@ namespace Util
         std::snprintf(buf.get(), sz, format.c_str(), args ...);
         return std::string(buf.get(), buf.get() + sz - 1); // -1 because we don't want the null terminator
     }
+    Json::Value readJsonFile(const std::string& path);
+    std::string transformGamename(const std::string& gamename);
 }
 
 #endif // UTIL_H
