@@ -47,25 +47,6 @@ int main(int argc, char *argv[])
 
     rhash_library_init();
 
-    // Constants for option selection with include/exclude
-    /* TODO: Add options to give better control for user
-             For example: option to select base game and DLC installers separately,
-             this requires some changes to Downloader class to implement */
-    const unsigned int OPTION_INSTALLERS = 1 << 0;
-    const unsigned int OPTION_EXTRAS     = 1 << 1;
-    const unsigned int OPTION_PATCHES    = 1 << 2;
-    const unsigned int OPTION_LANGPACKS  = 1 << 3;
-    const unsigned int OPTION_DLCS       = 1 << 4;
-
-    const std::vector<GlobalConstants::optionsStruct> INCLUDE_OPTIONS =
-    {
-        { OPTION_INSTALLERS, "i", "Installers",     "i|installers"              },
-        { OPTION_EXTRAS,     "e", "Extras",         "e|extras"                  },
-        { OPTION_PATCHES,    "p", "Patches",        "p|patches"                 },
-        { OPTION_LANGPACKS,  "l", "Language packs", "l|languagepacks|langpacks" },
-        { OPTION_DLCS,       "d", "DLCs",           "d|dlc|dlcs"                }
-    };
-
     Globals::globalConfig.sVersionString = VERSION_STRING;
     Globals::globalConfig.sVersionNumber = VERSION_NUMBER;
     Globals::globalConfig.curlConf.sUserAgent = DEFAULT_USER_AGENT;
@@ -79,6 +60,7 @@ int main(int argc, char *argv[])
     Globals::globalConfig.sBlacklistFilePath = Globals::globalConfig.sConfigDirectory + "/blacklist.txt";
     Globals::globalConfig.sIgnorelistFilePath = Globals::globalConfig.sConfigDirectory + "/ignorelist.txt";
     Globals::globalConfig.sGameHasDLCListFilePath = Globals::globalConfig.sConfigDirectory + "/game_has_dlc.txt";
+    Globals::globalConfig.sTransformConfigFilePath = Globals::globalConfig.sConfigDirectory + "/transformations.json";
 
     Globals::galaxyConf.setFilepath(Globals::globalConfig.sConfigDirectory + "/galaxy_tokens.json");
 
@@ -151,14 +133,15 @@ int main(int argc, char *argv[])
     std::string check_orphans_text = "Check for orphaned files (files found on local filesystem that are not found on GOG servers). Sets regular expression filter (Perl syntax) for files to check. If no argument is given then the regex defaults to '" + orphans_regex_default + "'";
 
     // Help text for subdir options
-    std::string subdir_help_text = "\nTemplates:\n- %platform%\n- %gamename%\n- %gamename_firstletter%\n- %dlcname%";
+    std::string subdir_help_text = "\nTemplates:\n- %platform%\n- %gamename%\n- %gamename_firstletter%\n- %dlcname%\n- %gamename_transformed%\n- %gamename_transformed_firstletter%";
 
     // Help text for include and exclude options
     std::string include_options_text;
-    for (unsigned int i = 0; i < INCLUDE_OPTIONS.size(); ++i)
+    for (unsigned int i = 0; i < GlobalConstants::INCLUDE_OPTIONS.size(); ++i)
     {
-        include_options_text +=  INCLUDE_OPTIONS[i].str + " = " + INCLUDE_OPTIONS[i].regexp + "\n";
+        include_options_text += GlobalConstants::INCLUDE_OPTIONS[i].str + " = " + GlobalConstants::INCLUDE_OPTIONS[i].regexp + "\n";
     }
+    include_options_text += "All = all\n";
     include_options_text += "Separate with \",\" to use multiple values";
 
     // Create help text for --list-format option
@@ -202,6 +185,7 @@ int main(int argc, char *argv[])
         bool bNoPlatformDetection = false;
         bool bNoGalaxyDependencies = false;
         bool bUseDLCList = false;
+        bool bNoFastStatusCheck = false;
         std::string sInstallerPlatform;
         std::string sInstallerLanguage;
         std::string sIncludeOptions;
@@ -224,9 +208,11 @@ int main(int argc, char *argv[])
             ("create-xml", bpo::value<std::string>(&Globals::globalConfig.sXMLFile)->implicit_value("automatic"), "Create GOG XML for file\n\"automatic\" to enable automatic XML creation")
             ("notifications", bpo::value<bool>(&Globals::globalConfig.bNotifications)->zero_tokens()->default_value(false), "Check notifications")
             ("updated", bpo::value<bool>(&Globals::globalConfig.bUpdated)->zero_tokens()->default_value(false), "List/download only games with update flag set")
+            ("new", bpo::value<bool>(&Globals::globalConfig.bNew)->zero_tokens()->default_value(false), "List/download only games with new flag set")
             ("clear-update-flags", bpo::value<bool>(&bClearUpdateNotifications)->zero_tokens()->default_value(false), "Clear update notification flags")
             ("check-orphans", bpo::value<std::string>(&Globals::globalConfig.sOrphanRegex)->implicit_value(""), check_orphans_text.c_str())
-            ("status", bpo::value<bool>(&Globals::globalConfig.bCheckStatus)->zero_tokens()->default_value(false), "Show status of files\n\nOutput format:\nstatuscode gamename filename filesize filehash\n\nStatus codes:\nOK - File is OK\nND - File is not downloaded\nMD5 - MD5 mismatch, different version\nFS - File size mismatch, incomplete download")
+            ("delete-orphans", bpo::value<bool>(&Globals::globalConfig.dlConf.bDeleteOrphans)->zero_tokens()->default_value(false), "Delete orphaned files during --check-orphans and --galaxy-install")
+            ("status", bpo::value<bool>(&Globals::globalConfig.bCheckStatus)->zero_tokens()->default_value(false), "Show status of files\n\nOutput format:\nstatuscode gamename filename filesize filehash\n\nStatus codes:\nOK - File is OK\nND - File is not downloaded\nMD5 - MD5 mismatch, different version\nFS - File size mismatch, incomplete download\n\nSee also --no-fast-status-check option")
             ("save-config", bpo::value<bool>(&Globals::globalConfig.bSaveConfig)->zero_tokens()->default_value(false), "Create config file with current settings")
             ("reset-config", bpo::value<bool>(&Globals::globalConfig.bResetConfig)->zero_tokens()->default_value(false), "Reset config settings to default")
             ("report", bpo::value<std::string>(&Globals::globalConfig.sReportFilePath)->implicit_value("lgogdownloader-report.log"), "Save report of downloaded/repaired files to specified file\nDefault filename: lgogdownloader-report.log")
@@ -275,6 +261,7 @@ int main(int argc, char *argv[])
             ("use-cache", bpo::value<bool>(&Globals::globalConfig.bUseCache)->zero_tokens()->default_value(false), ("Use game details cache"))
             ("cache-valid", bpo::value<int>(&Globals::globalConfig.iCacheValid)->default_value(2880), ("Set how long cached game details are valid (in minutes)\nDefault: 2880 minutes (48 hours)"))
             ("save-serials", bpo::value<bool>(&Globals::globalConfig.dlConf.bSaveSerials)->zero_tokens()->default_value(false), "Save serial numbers when downloading")
+            ("save-logo", bpo::value<bool>(&Globals::globalConfig.dlConf.bSaveLogo)->zero_tokens()->default_value(false), "Save logo when downloading")
             ("ignore-dlc-count", bpo::value<std::string>(&Globals::globalConfig.sIgnoreDLCCountRegex)->implicit_value(".*"), "Set regular expression filter for games to ignore DLC count information\nIgnoring DLC count information helps in situations where the account page doesn't provide accurate information about DLCs")
             ("include", bpo::value<std::string>(&sIncludeOptions)->default_value("all"), ("Select what to download/list/repair\n" + include_options_text).c_str())
             ("exclude", bpo::value<std::string>(&sExcludeOptions)->default_value(""), ("Select what not to download/list/repair\n" + include_options_text).c_str())
@@ -290,6 +277,8 @@ int main(int argc, char *argv[])
             ("include-hidden-products", bpo::value<bool>(&Globals::globalConfig.bIncludeHiddenProducts)->zero_tokens()->default_value(false), "Include games that have been set hidden in account page")
             ("size-only", bpo::value<bool>(&Globals::globalConfig.bSizeOnly)->zero_tokens()->default_value(false), "Don't check the hashes of the files whose size matches that on the server")
             ("verbosity", bpo::value<int>(&Globals::globalConfig.iMsgLevel)->default_value(0), "Set message verbosity level\n -1 = Less verbose\n 0 = Default\n 1 = Verbose\n 2 = Debug")
+            ("check-free-space", bpo::value<bool>(&Globals::globalConfig.dlConf.bFreeSpaceCheck)->zero_tokens()->default_value(false), "Check for available free space before starting download")
+            ("no-fast-status-check", bpo::value<bool>(&bNoFastStatusCheck)->zero_tokens()->default_value(false), "Don't use fast status check.\nMakes --status much slower but able to catch corrupted files by calculating local file hash for all files.")
         ;
 
         options_cli_no_cfg_hidden.add_options()
@@ -311,7 +300,6 @@ int main(int argc, char *argv[])
             ("galaxy-no-dependencies", bpo::value<bool>(&bNoGalaxyDependencies)->zero_tokens()->default_value(false), "Don't download dependencies during --galaxy-install")
             ("subdir-galaxy-install", bpo::value<std::string>(&Globals::globalConfig.dirConf.sGalaxyInstallSubdir)->default_value("%install_dir%"), galaxy_install_subdir_text.c_str())
             ("galaxy-cdn-priority", bpo::value<std::string>(&sGalaxyCDN)->default_value("edgecast,highwinds,akamai,lumen,gog_cdn"), galaxy_cdn_priority_text.c_str())
-            ("galaxy-delete-orphans", bpo::value<bool>(&Globals::globalConfig.dlConf.bGalaxyDeleteOrphans)->zero_tokens()->default_value(false), "Delete orphaned files during --galaxy-install")
         ;
 
         options_cli_all.add(options_cli_no_cfg).add(options_cli_cfg).add(options_cli_experimental);
@@ -431,6 +419,11 @@ int main(int argc, char *argv[])
             }
         }
 
+        if (boost::filesystem::exists(Globals::globalConfig.sTransformConfigFilePath))
+        {
+            Globals::globalConfig.transformationsJSON = Util::readJsonFile(Globals::globalConfig.sTransformConfigFilePath);
+        }
+
         if (!bUseDLCList)
             Globals::globalConfig.sGameHasDLCList = "";
 
@@ -525,6 +518,7 @@ int main(int argc, char *argv[])
         Globals::globalConfig.dirConf.bSubDirectories = !bNoSubDirectories;
         Globals::globalConfig.bPlatformDetection = !bNoPlatformDetection;
         Globals::globalConfig.dlConf.bGalaxyDependencies = !bNoGalaxyDependencies;
+        Globals::globalConfig.bUseFastCheck = !bNoFastStatusCheck;
 
         for (auto i = unrecognized_options_cli.begin(); i != unrecognized_options_cli.end(); ++i)
             if (i->compare(0, GlobalConstants::PROTOCOL_PREFIX.length(), GlobalConstants::PROTOCOL_PREFIX) == 0)
@@ -569,22 +563,14 @@ int main(int argc, char *argv[])
         std::vector<std::string> vExclude = Util::tokenize(sExcludeOptions, ",");
         for (std::vector<std::string>::iterator it = vInclude.begin(); it != vInclude.end(); it++)
         {
-            include_value |= Util::getOptionValue(*it, INCLUDE_OPTIONS);
+            include_value |= Util::getOptionValue(*it, GlobalConstants::INCLUDE_OPTIONS);
         }
         for (std::vector<std::string>::iterator it = vExclude.begin(); it != vExclude.end(); it++)
         {
-            exclude_value |= Util::getOptionValue(*it, INCLUDE_OPTIONS);
+            exclude_value |= Util::getOptionValue(*it, GlobalConstants::INCLUDE_OPTIONS);
         }
         Globals::globalConfig.dlConf.iInclude = include_value & ~exclude_value;
 
-        // Assign values
-        // TODO: Use config.iInclude in Downloader class directly and get rid of this value assignment
-        Globals::globalConfig.dlConf.bInstallers = (Globals::globalConfig.dlConf.iInclude & OPTION_INSTALLERS);
-        Globals::globalConfig.dlConf.bExtras = (Globals::globalConfig.dlConf.iInclude & OPTION_EXTRAS);
-        Globals::globalConfig.dlConf.bPatches = (Globals::globalConfig.dlConf.iInclude & OPTION_PATCHES);
-        Globals::globalConfig.dlConf.bLanguagePacks = (Globals::globalConfig.dlConf.iInclude & OPTION_LANGPACKS);
-        Globals::globalConfig.dlConf.bDLC = (Globals::globalConfig.dlConf.iInclude & OPTION_DLCS);
-
         Globals::globalConfig.iListFormat = Util::getOptionValue(sListFormat, GlobalConstants::LIST_FORMAT, false);
     }
     catch (std::exception& e)
