@@ -258,7 +258,7 @@ std::vector<galaxyDepotItem> galaxyAPI::getDepotItemsVector(const std::string& h
 
     for (unsigned int i = 0; i < json["depot"]["items"].size(); ++i)
     {
-        if (!json["depot"]["items"][i]["chunks"].empty())
+        if (json["depot"]["items"][i]["chunks"].isArray())
         {
             galaxyDepotItem item;
             item.totalSizeCompressed = 0;
@@ -287,6 +287,8 @@ std::vector<galaxyDepotItem> galaxyAPI::getDepotItemsVector(const std::string& h
                 item.md5 = json["depot"]["items"][i]["md5"].asString();
             else if (json["depot"]["items"][i]["chunks"].size() == 1)
                 item.md5 = json["depot"]["items"][i]["chunks"][0]["md5"].asString();
+            else
+                item.md5 = std::string();
 
             items.push_back(item);
         }
@@ -310,47 +312,58 @@ gameDetails galaxyAPI::productInfoJsonToGameDetails(const Json::Value& json, con
     gamedetails.product_id = json["id"].asString();
     gamedetails.title = json["title"].asString();
     gamedetails.icon = "https:" + json["images"]["icon"].asString();
+    gamedetails.logo = "https:" + json["images"]["logo"].asString();
+
+    Util::replaceString(gamedetails.logo, "_glx_logo.jpg", ".jpg");
 
     if (json.isMember("changelog"))
         gamedetails.changelog = json["changelog"].asString();
 
-    if (dlConf.bInstallers)
+    if (dlConf.iInclude & GlobalConstants::GFTYPE_INSTALLER)
     {
-        gamedetails.installers = this->fileJsonNodeToGameFileVector(gamedetails.gamename, json["downloads"]["installers"], GFTYPE_INSTALLER, dlConf);
+        gamedetails.installers = this->fileJsonNodeToGameFileVector(gamedetails.gamename, json["downloads"]["installers"], GlobalConstants::GFTYPE_BASE_INSTALLER, dlConf);
     }
 
-    if (dlConf.bExtras)
+    if (dlConf.iInclude & GlobalConstants::GFTYPE_EXTRA)
     {
-        gamedetails.extras = this->fileJsonNodeToGameFileVector(gamedetails.gamename, json["downloads"]["bonus_content"], GFTYPE_EXTRA, dlConf);
+        gamedetails.extras = this->fileJsonNodeToGameFileVector(gamedetails.gamename, json["downloads"]["bonus_content"], GlobalConstants::GFTYPE_BASE_EXTRA, dlConf);
     }
 
-    if (dlConf.bPatches)
+    if (dlConf.iInclude & GlobalConstants::GFTYPE_PATCH)
     {
-        gamedetails.patches = this->fileJsonNodeToGameFileVector(gamedetails.gamename, json["downloads"]["patches"], GFTYPE_PATCH, dlConf);
+        gamedetails.patches = this->fileJsonNodeToGameFileVector(gamedetails.gamename, json["downloads"]["patches"], GlobalConstants::GFTYPE_BASE_PATCH, dlConf);
     }
 
-    if (dlConf.bLanguagePacks)
+    if (dlConf.iInclude & GlobalConstants::GFTYPE_LANGPACK)
     {
-        gamedetails.languagepacks = this->fileJsonNodeToGameFileVector(gamedetails.gamename, json["downloads"]["language_packs"], GFTYPE_LANGPACK, dlConf);
+        gamedetails.languagepacks = this->fileJsonNodeToGameFileVector(gamedetails.gamename, json["downloads"]["language_packs"], GlobalConstants::GFTYPE_BASE_LANGPACK, dlConf);
     }
 
-    if (dlConf.bDLC)
+    if (dlConf.iInclude & GlobalConstants::GFTYPE_DLC)
     {
         if (json.isMember("expanded_dlcs"))
         {
             for (unsigned int i = 0; i < json["expanded_dlcs"].size(); ++i)
             {
+                std::string dlc_id = json["expanded_dlcs"][i]["id"].asString();
+
+                if (!Globals::vOwnedGamesIds.empty())
+                {
+                    if (std::find(Globals::vOwnedGamesIds.begin(), Globals::vOwnedGamesIds.end(), dlc_id) == Globals::vOwnedGamesIds.end())
+                        continue;
+                }
+
                 gameDetails dlc_gamedetails = this->productInfoJsonToGameDetails(json["expanded_dlcs"][i], dlConf);
 
                 // Add DLC type to all DLC files
                 for (unsigned int j = 0; j < dlc_gamedetails.installers.size(); ++j)
-                    dlc_gamedetails.installers[j].type |= GFTYPE_DLC;
+                    dlc_gamedetails.installers[j].type = GlobalConstants::GFTYPE_DLC_INSTALLER;
                 for (unsigned int j = 0; j < dlc_gamedetails.extras.size(); ++j)
-                    dlc_gamedetails.extras[j].type |= GFTYPE_DLC;
+                    dlc_gamedetails.extras[j].type = GlobalConstants::GFTYPE_DLC_EXTRA;
                 for (unsigned int j = 0; j < dlc_gamedetails.patches.size(); ++j)
-                    dlc_gamedetails.patches[j].type |= GFTYPE_DLC;
+                    dlc_gamedetails.patches[j].type = GlobalConstants::GFTYPE_DLC_PATCH;
                 for (unsigned int j = 0; j < dlc_gamedetails.languagepacks.size(); ++j)
-                    dlc_gamedetails.languagepacks[j].type |= GFTYPE_DLC;
+                    dlc_gamedetails.languagepacks[j].type = GlobalConstants::GFTYPE_DLC_LANGPACK;
 
                 // Add DLC only if it has any files
                 if (!dlc_gamedetails.installers.empty() || !dlc_gamedetails.extras.empty() || !dlc_gamedetails.patches.empty() || !dlc_gamedetails.languagepacks.empty())
@@ -377,7 +390,7 @@ std::vector<gameFile> galaxyAPI::fileJsonNodeToGameFileVector(const std::string&
 
         unsigned int iPlatform = GlobalConstants::PLATFORM_WINDOWS;
         unsigned int iLanguage = GlobalConstants::LANGUAGE_EN;
-        if (!(type & GFTYPE_EXTRA))
+        if (!(type & GlobalConstants::GFTYPE_EXTRA))
         {
             iPlatform = Util::getOptionValue(infoNode["os"].asString(), GlobalConstants::PLATFORMS);
             iLanguage = Util::getOptionValue(infoNode["language"].asString(), GlobalConstants::LANGUAGES);
@@ -425,7 +438,7 @@ std::vector<gameFile> galaxyAPI::fileJsonNodeToGameFileVector(const std::string&
             gf.galaxy_downlink_json_url = downlink;
             gf.version = version;
 
-            if (!(type & GFTYPE_EXTRA))
+            if (!(type & GlobalConstants::GFTYPE_EXTRA))
             {
                 gf.platform = iPlatform;
                 gf.language = iLanguage;
@@ -438,7 +451,7 @@ std::vector<gameFile> galaxyAPI::fileJsonNodeToGameFileVector(const std::string&
                 {
                     if (gamefiles[k].path == gf.path)
                     {
-                        if (!(type & GFTYPE_EXTRA))
+                        if (!(type & GlobalConstants::GFTYPE_EXTRA))
                             gamefiles[k].language |= gf.language; // Add language code to installer
                         bDuplicate = true;
                         break;
