@@ -82,7 +82,13 @@ void gameDetails::makeFilepaths(const DirectoryConfig& config)
     std::string filepath;
     std::string directory = config.sDirectory + "/" + config.sGameSubdir + "/";
     std::string subdir;
+    std::string logo_ext = ".jpg"; // Assume jpg
+
+    if (this->logo.rfind(".") != std::string::npos)
+        logo_ext = this->logo.substr(this->logo.rfind("."));
+
     this->serialsFilepath = Util::makeFilepath(directory, "serials.txt", this->gamename, subdir, 0);
+    this->logoFilepath = Util::makeFilepath(directory, "logo" + logo_ext, this->gamename, subdir, 0);
     this->changelogFilepath = Util::makeFilepath(directory, "changelog_" + gamename + ".html", this->gamename, subdir, 0);
 
     for (unsigned int i = 0; i < this->installers.size(); ++i)
@@ -117,6 +123,7 @@ void gameDetails::makeFilepaths(const DirectoryConfig& config)
     {
         subdir = config.bSubDirectories ? config.sDLCSubdir + "/" + config.sInstallersSubdir : "";
         this->dlcs[i].serialsFilepath = Util::makeFilepath(directory, "serials.txt", this->gamename, subdir, 0);
+        this->dlcs[i].logoFilepath = Util::makeFilepath(directory, "logo" + logo_ext, this->gamename, subdir, 0);
         this->dlcs[i].changelogFilepath = Util::makeFilepath(directory, "changelog_" + this->dlcs[i].gamename + ".html", this->gamename, subdir, 0);
         for (unsigned int j = 0; j < this->dlcs[i].installers.size(); ++j)
         {
@@ -184,6 +191,11 @@ std::string gameDetails::getSerialsFilepath()
     return this->serialsFilepath;
 }
 
+std::string gameDetails::getLogoFilepath()
+{
+    return this->logoFilepath;
+}
+
 std::string gameDetails::getChangelogFilepath()
 {
     return this->changelogFilepath;
@@ -214,27 +226,39 @@ std::vector<gameFile> gameDetails::getGameFileVector()
 // Return vector containing all game files matching download filters
 std::vector<gameFile> gameDetails::getGameFileVectorFiltered(const unsigned int& iType)
 {
-    std::vector<gameFile> vGameFiles = this->getGameFileVector();
+    std::vector<gameFile> vGameFiles;
 
-    std::remove_if(
-        vGameFiles.begin(),
-        vGameFiles.end(),
-        [iType](gameFile gf)
-        {
-            bool bRemove = false;
-            if (gf.type & iType)
-            {
-                // Remove if DLC but DLCs not enabled
-                if ( !((iType & GFTYPE_DLC) & iType) )
-                    bRemove = true;
-            }
-            else
-            {
-                bRemove = true;
-            }
-            return bRemove;
-        }
-    );
+    for (auto gf : this->getGameFileVector())
+    {
+        if (gf.type & iType)
+            vGameFiles.push_back(gf);
+    }
 
     return vGameFiles;
 }
+
+void gameDetails::filterWithType(const unsigned int& iType)
+{
+    filterListWithType(installers, iType);
+    filterListWithType(patches, iType);
+    filterListWithType(extras, iType);
+    filterListWithType(languagepacks, iType);
+    for (unsigned int i = 0; i < dlcs.size(); ++i)
+    {
+        filterListWithType(dlcs[i].installers, iType);
+        filterListWithType(dlcs[i].patches, iType);
+        filterListWithType(dlcs[i].extras, iType);
+        filterListWithType(dlcs[i].languagepacks, iType);
+    }
+}
+
+void gameDetails::filterListWithType(std::vector<gameFile>& list, const unsigned int& iType)
+{
+    for (std::vector<gameFile>::iterator gf = list.begin(); gf != list.end();)
+    {
+        if (!(gf->type & iType))
+            gf = list.erase(gf);
+        else
+            gf++;
+    }
+}
