@@ -330,9 +330,19 @@ int Util::getGameSpecificConfig(std::string gamename, gameSpecificConfig* conf,
         }
         res++;
     }
+    // Warn about deprecated option
     if (root.isMember("dlc"))
     {
-        conf->dlConf.bDLC = root["dlc"].asBool();
+        std::cerr << filepath << " contains deprecated option \"dlc\" which will be ignored, use \"include\" instead" << std::endl;
+    }
+    if (root.isMember("include"))
+    {
+        conf->dlConf.iInclude = 0;
+        std::vector<std::string> vInclude = Util::tokenize(root["include"].asString(), ",");
+        for (std::vector<std::string>::iterator it = vInclude.begin(); it != vInclude.end(); it++)
+        {
+            conf->dlConf.iInclude |= Util::getOptionValue(*it, GlobalConstants::INCLUDE_OPTIONS);
+        }
         res++;
     }
     if (root.isMember("ignore-dlc-count"))
@@ -438,6 +448,22 @@ void Util::filepathReplaceReservedStrings(std::string& str, const std::string& g
             gamename_firstletter = gamename.front();
     }
 
+    if (str.find("%gamename_transformed%") != std::string::npos || str.find("%gamename_transformed_firstletter%") != std::string::npos)
+    {
+        std::string gamename_transformed = transformGamename(gamename);
+        std::string gamename_transformed_firstletter;
+        if (!gamename_transformed.empty())
+        {
+            if (std::isdigit(gamename_transformed.front()))
+                gamename_transformed_firstletter = "0";
+            else
+                gamename_transformed_firstletter = gamename_transformed.front();
+        }
+
+        while (Util::replaceString(str, "%gamename_transformed%", gamename_transformed));
+        while (Util::replaceString(str, "%gamename_transformed_firstletter%", gamename_transformed_firstletter));
+    }
+
     while (Util::replaceString(str, "%gamename_firstletter%", gamename_firstletter));
     while (Util::replaceString(str, "%gamename%", gamename));
     while (Util::replaceString(str, "%dlcname%", dlcname));
@@ -480,18 +506,18 @@ int Util::getTerminalWidth()
 }
 
 
-void Util::getDownloaderUrlsFromJSON(const Json::Value &root, std::vector<std::string> &urls)
+void Util::getManualUrlsFromJSON(const Json::Value &root, std::vector<std::string> &urls)
 {
     if(root.size() > 0) {
         for(Json::ValueConstIterator it = root.begin() ; it != root.end() ; ++it)
         {
-            if (it.key() == "downloaderUrl")
+            if (it.key() == "manualUrl")
             {
                 Json::Value url = *it;
                 urls.push_back(url.asString());
             }
             else
-                getDownloaderUrlsFromJSON(*it, urls);
+                getManualUrlsFromJSON(*it, urls);
         }
     }
     return;
@@ -500,15 +526,14 @@ void Util::getDownloaderUrlsFromJSON(const Json::Value &root, std::vector<std::s
 std::vector<std::string> Util::getDLCNamesFromJSON(const Json::Value &root)
 {
     std::vector<std::string> urls, dlcnames;
-    getDownloaderUrlsFromJSON(root, urls);
+    getManualUrlsFromJSON(root, urls);
 
     for (unsigned int i = 0; i < urls.size(); ++i)
     {
         std::string gamename;
-        if (urls[i].find(GlobalConstants::PROTOCOL_PREFIX) == std::string::npos)
-            continue;
+        std::string url_prefix = "/downloads/";
 
-        gamename.assign(urls[i].begin()+urls[i].find(GlobalConstants::PROTOCOL_PREFIX)+GlobalConstants::PROTOCOL_PREFIX.length(), urls[i].begin()+urls[i].find_last_of("/"));
+        gamename.assign(urls[i].begin()+urls[i].find(url_prefix)+url_prefix.length(), urls[i].begin()+urls[i].find_last_of("/"));
         bool bDuplicate = false;
         for (unsigned int j = 0; j < dlcnames.size(); ++j)
         {
@@ -577,7 +602,8 @@ unsigned int Util::getOptionValue(const std::string& str, const std::vector<Glob
     boost::match_results<std::string::const_iterator> what;
     if (str == "all")
     {
-        value = (1 << options.size()) - 1;
+        for (unsigned int i = 0; i < options.size(); ++i)
+            value |= options[i].id;
     }
     else if (boost::regex_search(str, what, expression) && bAllowStringToIntConversion)
     {
@@ -612,7 +638,7 @@ std::string Util::getOptionNameString(const unsigned int& value, const std::vect
     std::string str;
     for (unsigned int i = 0; i < options.size(); ++i)
     {
-        if (value & options[i].id)
+        if ((value & options[i].id) == options[i].id)
             str += (str.empty() ? "" : ", ")+options[i].str;
     }
     return str;
@@ -637,7 +663,7 @@ void Util::parseOptionString(const std::string &option_string, std::vector<unsig
     }
 }
 
-std::string Util::getLocalFileHash(const std::string& xml_dir, const std::string& filepath, const std::string& gamename)
+std::string Util::getLocalFileHash(const std::string& xml_dir, const std::string& filepath, const std::string& gamename, const bool& useFastCheck)
 {
     std::string localHash;
     boost::filesystem::path path = filepath;
@@ -647,7 +673,7 @@ std::string Util::getLocalFileHash(const std::string& xml_dir, const std::string
     else
         local_xml_file = xml_dir + "/" + path.filename().string() + ".xml";
 
-    if (boost::filesystem::exists(local_xml_file))
+    if (boost::filesystem::exists(local_xml_file) && useFastCheck)
     {
         tinyxml2::XMLDocument local_xml;
         local_xml.LoadFile(local_xml_file.string().c_str());
@@ -894,3 +920,82 @@ curl_off_t Util::CurlReadChunkMemoryCallback(void *contents, curl_off_t size, cu
 
     return realsize;
 }
+
+std::string Util::makeSizeString(const unsigned long long& iSizeInBytes)
+{
+    auto units = { "B", "kB", "MB", "GB", "TB", "PB" };
+    std::string size_unit = "B";
+    double iSize = static_cast<double>(iSizeInBytes);
+    for (auto unit : units)
+    {
+        size_unit = unit;
+        if (iSize < 1024)
+            break;
+
+        iSize /= 1024;
+    }
+    return formattedString("%0.2f %s", iSize, size_unit.c_str());
+}
+
+Json::Value Util::readJsonFile(const std::string& path)
+{
+    Json::Value json;
+    std::ifstream ifs(path, std::ifstream::binary);
+
+    if (ifs)
+    {
+        try
+        {
+            ifs >> json;
+        }
+        catch (const Json::Exception& exc)
+        {
+            std::cerr << "Failed to parse " << path << std::endl;
+            std::cerr << exc.what() << std::endl;
+        }
+        ifs.close();
+    }
+    else
+    {
+        std::cerr << "Failed to open " << path << std::endl;
+    }
+
+    return json;
+}
+
+std::string Util::transformGamename(const std::string& gamename)
+{
+    std::string gamename_transformed = gamename;
+    for (auto transformMatch : Globals::globalConfig.transformationsJSON.getMemberNames())
+    {
+        boost::regex expression(transformMatch);
+        boost::match_results<std::string::const_iterator> what;
+        if (boost::regex_search(gamename_transformed, what, expression))
+        {
+            // Get list of exceptions
+            std::vector<std::string> vExceptions;
+            if (Globals::globalConfig.transformationsJSON[transformMatch].isMember("exceptions"))
+            {
+                if (Globals::globalConfig.transformationsJSON[transformMatch]["exceptions"].isArray())
+                {
+                    for (auto exception : Globals::globalConfig.transformationsJSON[transformMatch]["exceptions"])
+                        vExceptions.push_back(exception.asString());
+                }
+                else
+                {
+                    vExceptions.push_back(Globals::globalConfig.transformationsJSON[transformMatch]["exceptions"].asString());
+                }
+            }
+
+            // Skip if gamename matches exception
+            if (std::any_of(vExceptions.begin(), vExceptions.end(), [gamename](std::string exception){return exception == gamename;}))
+                continue;
+
+            boost::regex transformRegex(Globals::globalConfig.transformationsJSON[transformMatch]["regex"].asString());
+            std::string transformReplacement = Globals::globalConfig.transformationsJSON[transformMatch]["replacement"].asString();
+            gamename_transformed = boost::regex_replace(gamename_transformed, transformRegex, transformReplacement);
+        }
+    }
+
+    return gamename_transformed;
+}
